AliPayStatus enum

Inheritance
Available extensions

Values

success → const AliPayStatus

支付成功

fail → const AliPayStatus

支付失败

cancel → const AliPayStatus

支付取消

processing → const AliPayStatus

支付处理中

disconnected → const AliPayStatus

网络连接异常

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AliPayStatus>
A constant List of the values in this enum, in order of their declaration.