ShareInfo class
Constructors
Properties
- channel ↔ String
-
分享渠道(由组件内部获取)
getter/setter pair
- describe → String
-
分享信息
final
- extra → dynamic
-
扩展数据
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
图片地址
final
- platform ↔ String
-
分享平台 SharePlatform,由分享组件内部赋值
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
分享类型ShareType
final
- title → String
-
分享标题
final
- url → String?
-
根据分享类型:ShareType.image-标题链接(qq该项为空),ShareType.links-分享网页url,ShareType.text-该项为空
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited